/**
    @file ft51_sfr.h

    @brief FT51 Special Function Registers

    Defines each Special-Function Register (SFR) in the FT51's core.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_SFR_H__
#define __FT51_SFR_H__

#include <stdint.h>


/**
    @name       SFRs
    @brief      SFR declarations.

    Declarations for all of the available SFRs in the FT51 core.

**/
/**@{**/
__sfr __at (0x80) P0;
__sfr __at (0x81) SP;
__sfr __at (0x82) DPL;
__sfr __at (0x82) DPL0; // FT51 extension: second data pointer
__sfr __at (0x83) DPH;
__sfr __at (0x83) DPH0; // FT51 extension: second data pointer
__sfr __at (0x84) DPL1; // FT51 extension: second data pointer
__sfr __at (0x85) DPH1; // FT51 extension: second data pointer
__sfr __at (0x86) DPS;  // FT51 extension: select active data pointer
__sfr __at (0x87) PCON;
__sfr __at (0x88) TCON;
__sfr __at (0x89) TMOD;
__sfr __at (0x8A) TL0;
__sfr __at (0x8B) TL1;
__sfr __at (0x8C) TH0;
__sfr __at (0x8D) TH1;
__sfr __at (0x8E) CKCON; // FT51 extension: control timer tick
__sfr __at (0x90) P1;
__sfr __at (0x91) EIF;   // FT51 extension: I2C interrupt flags
__sfr __at (0x94) IO_DATA_9;
__sfr __at (0x98) SCON;
__sfr __at (0x99) SBUF;
__sfr __at (0x9A) IO_ADDR_0_H;
__sfr __at (0x9B) IO_ADDR_0_L;
__sfr __at (0x9C) IO_DATA_0;
__sfr __at (0x9D) IO_ADDR_1_H;
__sfr __at (0x9E) IO_ADDR_1_L;
__sfr __at (0x9F) IO_DATA_1;
__sfr __at (0xA0) P2;
__sfr __at (0xA8) IE;
__sfr __at (0xA9) IO_ADDR_2_H;
__sfr __at (0xAA) IO_ADDR_2_L;
__sfr __at (0xAB) IO_DATA_2;
__sfr __at (0xB0) P3;
__sfr __at (0xB1) IO_ADDR_3_H;
__sfr __at (0xB2) IO_ADDR_3_L;
__sfr __at (0xB3) IO_DATA_3;
__sfr __at (0xB8) IP;
__sfr __at (0xB9) IO_ADDR_4_H;
__sfr __at (0xBA) IO_ADDR_4_L;
__sfr __at (0xBB) IO_DATA_4;
__sfr __at (0xC8) T2CON;  // FT51 extension: Timer 2
__sfr __at (0xC9) T2IF;   // FT51 extension: Timer 2
__sfr __at (0xCA) RCAP2L; // FT51 extension: Timer 2
__sfr __at (0xCB) RCAP2H; // FT51 extension: Timer 2
__sfr __at (0xCC) TL2;    // FT51 extension: Timer 2
__sfr __at (0xCD) TH2;    // FT51 extension: Timer 2
__sfr __at (0xD0) PSW;
__sfr __at (0xD1) IO_ADDR_5_H;
__sfr __at (0xD2) IO_ADDR_5_L;
__sfr __at (0xD3) IO_DATA_5;
__sfr __at (0xD9) IO_ADDR_6_H;
__sfr __at (0xDA) IO_ADDR_6_L;
__sfr __at (0xDB) IO_DATA_6;
__sfr __at (0xE0) ACC;
__sfr __at (0xE0) A;
__sfr __at (0xE1) IO_ADDR_7_H;
__sfr __at (0xE2) IO_ADDR_7_L;
__sfr __at (0xE3) IO_DATA_7;
__sfr __at (0xE8) EIE;     // FT51 extension: I2C interrupt enable
__sfr __at (0xE9) STATUS;
__sfr __at (0xF0) B;
__sfr __at (0xF1) I2CSOA;  // FT51 extension: I2C Slave
__sfr __at (0xF2) I2CSCR;  // FT51 extension: I2C Slave
__sfr __at (0xF2) I2CSSR;  // FT51 extension: I2C Slave
__sfr __at (0xF3) I2CSBUF; // FT51 extension: I2C Slave
__sfr __at (0xF4) I2CMSA;  // FT51 extension: I2C Master
__sfr __at (0xF5) I2CMCR;  // FT51 extension: I2C Master
__sfr __at (0xF5) I2CMSR;  // FT51 extension: I2C Master
__sfr __at (0xF6) I2CMBUF; // FT51 extension: I2C Master
__sfr __at (0xF7) I2CMTP;  // FT51 extension: I2C Master
__sfr __at (0xF8) EIP;     // FT51 extension: I2C interrupt priority
__sfr __at (0xF9) IO_ADDR_8_H;
__sfr __at (0xFA) IO_ADDR_8_L;
__sfr __at (0xFB) IO_DATA_8;
__sfr __at (0xFC) FT122_CMD;  // FT51 extension: USB Slave
__sfr __at (0xFD) FT122_DATA; // FT51 extension: USB Slave
__sfr __at (0xFE) IO_ADDR_9_H;
__sfr __at (0xFF) IO_ADDR_9_L;
/**@}**/

// Port 0 bit-addressable pins
__sbit __at (0x80) P0_0;
__sbit __at (0x81) P0_1;
__sbit __at (0x82) P0_2;
__sbit __at (0x83) P0_3;
__sbit __at (0x84) P0_4;
__sbit __at (0x85) P0_5;
__sbit __at (0x86) P0_6;
__sbit __at (0x87) P0_7;

// Port 1 bit-addressable pins
__sbit __at (0x90) P1_0;
__sbit __at (0x91) P1_1;
__sbit __at (0x92) P1_2;
__sbit __at (0x93) P1_3;
__sbit __at (0x94) P1_4;
__sbit __at (0x95) P1_5;
__sbit __at (0x96) P1_6;
__sbit __at (0x97) P1_7;

// Port 2 bit-addressable pins
__sbit __at (0xA0) P2_0;
__sbit __at (0xA1) P2_1;
__sbit __at (0xA2) P2_2;
__sbit __at (0xA3) P2_3;
__sbit __at (0xA4) P2_4;
__sbit __at (0xA5) P2_5;
__sbit __at (0xA6) P2_6;
__sbit __at (0xA7) P2_7;

// Port 3 bit-addressable pins
__sbit __at (0xB0) P3_0;
__sbit __at (0xB1) P3_1;
__sbit __at (0xB2) P3_2;
__sbit __at (0xB3) P3_3;
__sbit __at (0xB4) P3_4;
__sbit __at (0xB5) P3_5;
__sbit __at (0xB6) P3_6;
__sbit __at (0xB7) P3_7;

__at (0) uint8_t R0;
__at (1) uint8_t R1;
__at (2) uint8_t R2;
__at (3) uint8_t R3;
__at (4) uint8_t R4;
__at (5) uint8_t R5;
__at (6) uint8_t R6;
__at (7) uint8_t R7;

// TCON bits
__sbit __at (0x88) IT0;
__sbit __at (0x89) IE0;
__sbit __at (0x8A) IT1;
__sbit __at (0x8B) IE1;
__sbit __at (0x8C) TR0;
__sbit __at (0x8D) TF0;
__sbit __at (0x8E) TR1;
__sbit __at (0x8F) TF1;

// SCON
__sbit __at (0x98) RI;
__sbit __at (0x99) TI;
__sbit __at (0x9A) RB8;
__sbit __at (0x9B) TB8;
__sbit __at (0x9C) REN;
__sbit __at (0x9D) SM2;
__sbit __at (0x9E) SM1;
__sbit __at (0x9F) SM0;

// IE
__sbit __at (0xA8) EX0;
__sbit __at (0xA9) ET0;
__sbit __at (0xAA) EX1;
__sbit __at (0xAB) ET1;
__sbit __at (0xAC) ES;
__sbit __at (0xAD) ET2;
__sbit __at (0xAF) EA;

// CKCON
#define TIMER_0_DIV4  8 // timer 0 tick = 4 clocks instead of 12 clocks
#define TIMER_1_DIV4 16 // timer 1 tick = 4 clocks instead of 12 clocks
#define TIMER_2_DIV4 32 // timer 2 tick = 4 clocks instead of 12 clocks

#endif // __FT51_SFR_H__