/**
    @file ft51_iomux_registers.h

    @brief IO MUX registers library

    Defines registers and bit-masks for the IO multiplexer which maps signals to pads.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_IOMUX_REGISTERS_H__
#define __FT51_IOMUX_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 64 (0x40) IOMUX_CONTROL
#define IOMUX_CONTROL                         0x40

// Register 64 Bit Definitions
#define BIT_IOMUX_SOFT_RESET                  0                                 // Write a 1 to reset IOMUX
#define MASK_IOMUX_SOFT_RESET                 (0x1 << BIT_IOMUX_SOFT_RESET)
#define BIT_IOMUX_DEV_EN                      1                                 // Write a 1 to enable IOMUX
#define MASK_IOMUX_DEV_EN                     (0x1 << BIT_IOMUX_DEV_EN)

//------------------------------------------------------------------------------
// Register 65 (0x41) IOMUX_OUTPUT_PAD_SEL
#define IOMUX_OUTPUT_PAD_SEL                    0x41

// Register 65 Bit Definitions
#define BIT_OP_PAD_SEL_0                      0                                 // Select the output pad first
#define MASK_OP_PAD_SEL_0                     (0x1 << BIT_OP_PAD_SEL_0)
#define BIT_OP_PAD_SEL_1                      1                                 // Select the output pad first
#define MASK_OP_PAD_SEL_1                     (0x1 << BIT_OP_PAD_SEL_1)
#define BIT_OP_PAD_SEL_2                      2                                 // Select the output pad first
#define MASK_OP_PAD_SEL_2                     (0x1 << BIT_OP_PAD_SEL_2)
#define BIT_OP_PAD_SEL_3                      3                                 // Select the output pad first
#define MASK_OP_PAD_SEL_3                     (0x1 << BIT_OP_PAD_SEL_3)
#define BIT_OP_PAD_SEL_4                      4                                 // Select the output pad first
#define MASK_OP_PAD_SEL_4                     (0x1 << BIT_OP_PAD_SEL_4)
#define BIT_OP_PAD_SEL_5                      5                                 // Select the output pad first
#define MASK_OP_PAD_SEL_5                     (0x1 << BIT_OP_PAD_SEL_5)
#define BIT_OP_PAD_SEL_6                      6                                 // Select the output pad first
#define MASK_OP_PAD_SEL_6                     (0x1 << BIT_OP_PAD_SEL_6)
#define BIT_OP_PAD_SEL_7                      7                                 // Select the output pad first
#define MASK_OP_PAD_SEL_7                     (0x1 << BIT_OP_PAD_SEL_7)
#define MASK_OP_PAD_SEL                       (0xFF << BIT_OP_PAD_SEL_0)

//------------------------------------------------------------------------------
// Register 66 (0x42) IOMUX_OUTPUT_SIG_SEL
#define IOMUX_OUTPUT_SIG_SEL                    0x42

// Register 66 Bit Definitions
#define BIT_OP_SIG_SEL_0                      0                                 // Select the output source second
#define MASK_OP_SIG_SEL_0                     (0x1 << BIT_OP_SIG_SEL_0)
#define BIT_OP_SIG_SEL_1                      1                                 // Select the output source second
#define MASK_OP_SIG_SEL_1                     (0x1 << BIT_OP_SIG_SEL_1)
#define BIT_OP_SIG_SEL_2                      2                                 // Select the output source second
#define MASK_OP_SIG_SEL_2                     (0x1 << BIT_OP_SIG_SEL_2)
#define BIT_OP_SIG_SEL_3                      3                                 // Select the output source second
#define MASK_OP_SIG_SEL_3                     (0x1 << BIT_OP_SIG_SEL_3)
#define BIT_OP_SIG_SEL_4                      4                                 // Select the output source second
#define MASK_OP_SIG_SEL_4                     (0x1 << BIT_OP_SIG_SEL_4)
#define BIT_OP_SIG_SEL_5                      5                                 // Select the output source second
#define MASK_OP_SIG_SEL_5                     (0x1 << BIT_OP_SIG_SEL_5)
#define BIT_OP_SIG_SEL_6                      6                                 // Select the output source second
#define MASK_OP_SIG_SEL_6                     (0x1 << BIT_OP_SIG_SEL_6)
#define BIT_OP_SIG_SEL_7                      7                                 // Select the output source second
#define MASK_OP_SIG_SEL_7                     (0x1 << BIT_OP_SIG_SEL_7)
#define MASK_OP_SIG_SEL                       (0xFF << BIT_OP_SIG_SEL_0)

//------------------------------------------------------------------------------
// Register 67 (0x43) IOMUX_INPUT_SIG_SEL
#define IOMUX_INPUT_SIG_SEL                    0x43

// Register 67 Bit Definitions
#define BIT_IP_SIG_SEL_0                      0                                 // Select the input sink first
#define MASK_IP_SIG_SEL_0                     (0x1 << BIT_IP_SIG_SEL_0)
#define BIT_IP_SIG_SEL_1                      1                                 // Select the input sink first
#define MASK_IP_SIG_SEL_1                     (0x1 << BIT_IP_SIG_SEL_1)
#define BIT_IP_SIG_SEL_2                      2                                 // Select the input sink first
#define MASK_IP_SIG_SEL_2                     (0x1 << BIT_IP_SIG_SEL_2)
#define BIT_IP_SIG_SEL_3                      3                                 // Select the input sink first
#define MASK_IP_SIG_SEL_3                     (0x1 << BIT_IP_SIG_SEL_3)
#define BIT_IP_SIG_SEL_4                      4                                 // Select the input sink first
#define MASK_IP_SIG_SEL_4                     (0x1 << BIT_IP_SIG_SEL_4)
#define BIT_IP_SIG_SEL_5                      5                                 // Select the input sink first
#define MASK_IP_SIG_SEL_5                     (0x1 << BIT_IP_SIG_SEL_5)
#define BIT_IP_SIG_SEL_6                      6                                 // Select the input sink first
#define MASK_IP_SIG_SEL_6                     (0x1 << BIT_IP_SIG_SEL_6)
#define BIT_IP_SIG_SEL_7                      7                                 // Select the input sink first
#define MASK_IP_SIG_SEL_7                     (0x1 << BIT_IP_SIG_SEL_7)
#define MASK_IP_SIG_SEL                       (0xFF << BIT_IP_SIG_SEL_0)

//------------------------------------------------------------------------------
// Register 68 (0x44) IOMUX_INPUT_PAD_SEL
#define IOMUX_INPUT_PAD_SEL                    0x44

// Register 68 Bit Definitions
#define BIT_IP_PAD_SEL_0                      0                                 // Select the input pad second
#define MASK_IP_PAD_SEL_0                     (0x1 << BIT_IP_PAD_SEL_0)
#define BIT_IP_PAD_SEL_1                      1                                 // Select the input pad second
#define MASK_IP_PAD_SEL_1                     (0x1 << BIT_IP_PAD_SEL_1)
#define BIT_IP_PAD_SEL_2                      2                                 // Select the input pad second
#define MASK_IP_PAD_SEL_2                     (0x1 << BIT_IP_PAD_SEL_2)
#define BIT_IP_PAD_SEL_3                      3                                 // Select the input pad second
#define MASK_IP_PAD_SEL_3                     (0x1 << BIT_IP_PAD_SEL_3)
#define BIT_IP_PAD_SEL_4                      4                                 // Select the input pad second
#define MASK_IP_PAD_SEL_4                     (0x1 << BIT_IP_PAD_SEL_4)
#define BIT_IP_PAD_SEL_5                      5                                 // Select the input pad second
#define MASK_IP_PAD_SEL_5                     (0x1 << BIT_IP_PAD_SEL_5)
#define BIT_IP_PAD_SEL_6                      6                                 // Select the input pad second
#define MASK_IP_PAD_SEL_6                     (0x1 << BIT_IP_PAD_SEL_6)
#define BIT_IP_PAD_SEL_7                      7                                 // Select the input pad second
#define MASK_IP_PAD_SEL_7                     (0x1 << BIT_IP_PAD_SEL_7)
#define MASK_IP_PAD_SEL                       (0xFF << BIT_IP_PAD_SEL_0)

#endif // __FT51_IOMUX_REGISTERS_H__
